import requests
import json

class Response(object):
  """The translation object"""
  def __init__(self,dictionary):
    self.res = dictionary['res']
    self.query = dictionary['query']

def cb(text):
    response = requests.get(f'https://bruhapi.xyz/cb/{text}')
    rej = json.loads(response.text)
    return Response(rej)

def sponge(text):
    response = requests.get(f'https://bruhapi.xyz/sponge/{text}')
    rej = json.loads(response.text)
    return rej['res']

def tts(text):
  response = requests.get(f'https://bruhapi.xyz/tts/{text}')
  rej = json.loads(response.text)
  return rej['res']


import bruhapy
import requests as req
import json
def taco():
    response = req.get(f'https://bruhapi.xyz/taco')
    if response.status_code != 200:
      raise bruhapy.RequestError("The endpoint is having an error, either it was moved or it is currently offline.")
    rej = json.loads(response.text)
    return rej['res']


import requests
import json

class Translation(object):
  """The translation object"""
  def __init__(self,dictionary):
    self.lang = dictionary['lang']
    self.tr = dictionary['text']
    self.original = dictionary['original']

def joke():
    response = requests.get(f'https://bruhapi.xyz/joke/')
    rej = json.loads(response.text)
    return rej['res']

def translate(text):
    response = requests.get(f'https://bruhapi.xyz/translate/{text}')
    rej = json.loads(response.text)
    return Translation(rej)